@@ -1,7 +1,7 @@
 /*
     Qalculate    
 
-    Copyright (C) 2004  Niklas Knutsson (nq@altern.org)
+    Copyright (C) 2004-2006  Niklas Knutsson (nq@altern.org)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -215,11 +215,11 @@ const string &DataProperty::getReferenceName() const {
 	}
 	return getName();
 }
-bool DataProperty::hasName(const string &s_name) {
+size_t DataProperty::hasName(const string &s_name) {
 	for(size_t i = 0; i < names.size(); i++) {
-		if(equalsIgnoreCase(s_name, names[i])) return true;
+		if(equalsIgnoreCase(s_name, names[i])) return i + 1;
 	}
-	return false;
+	return 0;
 }
 size_t DataProperty::countNames() const {
 	return names.size();
@@ -278,7 +278,7 @@ string DataProperty::getDisplayString(const string &valuestr) {
 	return str;
 }
 MathStructure *DataProperty::generateStruct(const string &valuestr, int is_approximate) {
-	MathStructure *mstruct;
+	MathStructure *mstruct = NULL;
 	switch(ptype) {
 		case PROPERTY_EXPRESSION: {
 			ParseOptions po;
@@ -509,15 +509,15 @@ bool DataSet::loadObjects(const char *file_name, bool is_user_defs) {
 		version_numbers[i] = s2i(version.substr(0, dot_i));
 		version = version.substr(dot_i + 1, version.length() - (dot_i + 1));
 	}
-	DataObject *o;
+	DataObject *o = NULL;
 	cur = cur->xmlChildrenNode;
 	string str, str2;
 	vector<DataProperty*> lang_status_p;
 	vector<int> lang_status;
-	int ils;
-	int i_approx;
-	bool cmp;
-	bool b, old_object;
+	int ils = 0;
+	int i_approx = 0;
+	bool cmp = false;
+	bool b = false, old_object = false;
 	size_t objects_before = objects.size();
 	vector<DataProperty*> p_refs;
 	vector<string> s_refs;
@@ -619,6 +619,16 @@ bool DataSet::loadObjects(const char *file_name, bool is_user_defs) {
 									if(value) {
 										str = (char*) value;
 										remove_blank_ends(str);
+										if(!str.empty() && str[0] == '!') {
+											size_t i4 = str.find('!', 1);
+											if(i4 != string::npos) {
+												if(i4 + 1 < str.length()) {
+													str = str.substr(i4 + 1, str.length() - (i4 + 1));
+												} else {
+													str = "";
+												}
+											}
+										}
 									} else {
 										str = ""; 
 									}
