@@ -1,7 +1,7 @@
 /*
     Qalculate    
 
-    Copyright (C) 2003-2006  Niklas Knutsson (nq@altern.org)
+    Copyright (C) 2003-2007  Niklas Knutsson (nq@altern.org)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -1116,7 +1116,10 @@ string Argument::printlong() const {
 		str += " ";
 		str += _("that fulfills the condition:");
 		str += " \"";
-		str += scondition;
+		string str2 = scondition;
+		if(name().empty()) gsub("\\x", _("Argument"), str2);
+		else gsub("\\x", name(), str2);
+		str += str2;
 		str += "\"";
 	}
 	return str;
