@@ -1,7 +1,7 @@
 /*
     Qalculate    
 
-    Copyright (C) 2004-2006  Niklas Knutsson (nq@altern.org)
+    Copyright (C) 2004-2007  Niklas Knutsson (nq@altern.org)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -363,6 +363,7 @@ class Number {
 		bool ln();	
 		bool log(const Number &o);
 		bool exp();
+		bool lambertW();
 		bool gcd(const Number &o);
 		bool lcm(const Number &o);
 		
@@ -370,6 +371,7 @@ class Number {
 		bool multiFactorial(const Number &o);
 		bool doubleFactorial();
 		bool binomial(const Number &m, const Number &k);
+		bool factorize(vector<Number> &factors);
 	
 		bool add(const Number &o, MathOperation op); 
 
