@@ -1,7 +1,7 @@
 /*
     Qalculate    
 
-    Copyright (C) 2003-2006  Niklas Knutsson (nq@altern.org)
+    Copyright (C) 2003-2007  Niklas Knutsson (nq@altern.org)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -724,11 +724,12 @@ void CompositeUnit::setBaseExpression(string base_expression_) {
 		setChanged(true);
 		return;
 	}
-	//fix!
 	EvaluationOptions eo;
 	eo.approximation = APPROXIMATION_EXACT;
 	eo.sync_units = false;
 	eo.keep_prefixes = true;
+	eo.structuring = STRUCTURING_NONE;
+	eo.reduce_divisions = false;
 	ParseOptions po;
 	po.variables_enabled = false;
 	po.functions_enabled = false;
