@@ -1,7 +1,7 @@
 /*
     Qalculate    
 
-    Copyright (C) 2003-2006  Niklas Knutsson (nq@altern.org)
+    Copyright (C) 2003-2007  Niklas Knutsson (nq@altern.org)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -44,6 +44,12 @@ int weekday(string str);
 int yearday(string str);
 void now(int &hour, int &min, int &sec);
 void today(int &year, int &month, int &day);
+bool addDays(int &year, int &month, int &day, int days);
+string addDays(string str, int days);
+bool addMonths(int &year, int &month, int &day, int months);
+string addMonths(string str, int months);
+bool addYears(int &year, int &month, int &day, int years);
+string addYears(string str, int years);
 bool s2date(string str, int &year, int &month, int &day);
 bool isLeapYear(int year);
 int daysPerYear(int year, int basis = 0);
