@@ -380,6 +380,11 @@ void print_function(MathFunction *f) {
 				if(i2 > f->minargs()) {
 					str2 += " (";
 					str2 += _("optional");
+					if(!f->getDefaultValue(i2).empty()) {
+						str2 += ", ";
+						str2 += _("default: ");
+						str2 += f->getDefaultValue(i2);
+					}
 					str2 += ")";
 				}
 				str += str2;
@@ -458,7 +463,7 @@ void print_variable(Variable *v) {
 				} else if(((KnownVariable*) v)->get().isVector()) {
 					value = _("vector");
 				} else {
-					value = fix(CALCULATOR->printMathStructureTimeOut(((KnownVariable*) v)->get(), 30000));
+					value = fix(CALCULATOR->printMathStructureTimeOut(((KnownVariable*) v)->get(), 30));
 				}
 			}
 		} else {
@@ -517,9 +522,9 @@ void print_unit(Unit *u) {
 			case SUBTYPE_ALIAS_UNIT: {
 				AliasUnit *au = (AliasUnit*) u;
 				base_unit = au->firstBaseUnit()->preferredDisplayName(printops.abbreviate_names, printops.use_unicode_signs).name;
-				if(au->firstBaseExp() != 1) {
+				if(au->firstBaseExponent() != 1) {
 					base_unit += POWER;
-					base_unit += i2s(au->firstBaseExp());
+					base_unit += i2s(au->firstBaseExponent());
 				}
 				if(au->firstBaseUnit() == CALCULATOR->u_euro && au->isBuiltin()) {
 					relation = "exchange rate";
